from .系统_取CPU型号 import 系统_取CPU型号
from .系统_取剪辑版内容 import 系统_取剪辑版内容
from .系统_取剪辑版内容到十六进制 import 系统_取剪辑版内容到十六进制
from .系统_取操作系统类别 import 系统_取操作系统类别
from .系统_取时区 import 系统_取时区
from .系统_取用户名 import 系统_取用户名
from .系统_取硬盘特征字 import 系统_取硬盘特征字
from .系统_取系统现行时间 import 系统_取系统现行时间
from .系统_强制关机 import 系统_强制关机
from .系统_强制注销 import 系统_强制注销
from .系统_强制重启 import 系统_强制重启
from .系统_是否为管理员 import 系统_是否为管理员
from .系统_是否已联网 import 系统_是否已联网
from .系统_清空回收站 import 系统_清空回收站
from .系统_生成随机mac import 系统_生成随机mac
from .系统_置剪辑版内容 import 系统_置剪辑版内容
from .系统_获取外网IP import 系统_获取外网IP
from .系统任务计划_删除 import 系统任务计划_删除
from .系统任务计划_遍历名称 import 系统任务计划_遍历名称